hir_has_fixed_length

Function hir_has_fixed_length 

pub(super) fn hir_has_fixed_length(hir: &Hir) -> bool
Returns true when the given Hir has a fixed length.

That is, when its minimum and maximum lengths are both finite and equivalent.